@@ -11,7 +11,7 @@ import time
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 logger = logging.getLogger(__name__)
 
@@ -346,7 +346,7 @@ class Connection(handler.Connection):
         self.aborted[req.conn_id] = (time.time(), req.sender)
 
     def remove_aborted(self, req):
-        del self.aborted[req.conn_id]
+        self.aborted.pop(req.conn_id, None)
 
     def cleanup_aborted(self):
         """this will cleanup the aborted connection cache, this was originally
